@@ -79,34 +79,25 @@ def run(
     select or exclude certain variables, optionally followed by specific comma-separated values.
     For example, if you have the following configuration:
 
-    === ":octicons-file-code-16: pyproject.toml"
-
-        \b
-        ```toml
-        [[tool.hatch.envs.test.matrix]]
-        python = ["39", "310"]
-        version = ["42", "3.14", "9000"]
-        ```
-
-    === ":octicons-file-code-16: hatch.toml"
-
-        \b
-        ```toml
-        [[envs.test.matrix]]
-        python = ["39", "310"]
-        version = ["42", "3.14", "9000"]
-        ```
+    \b
+    ```toml config-example
+    [[tool.hatch.envs.test.matrix]]
+    python = ["3.9", "3.10"]
+    version = ["42", "3.14", "9000"]
+    ```
 
     then running:
 
     \b
     ```
-    hatch env run -i py=310 -x version=9000 test:pytest
+    hatch env run -i py=3.10 -x version=9000 test:pytest
     ```
 
-    would execute `pytest` in the environments `test.py310-42` and `test.py310-3.14`.
+    would execute `pytest` in the environments `test.py3.10-42` and `test.py3.10-3.14`.
     Note that `py` may be used as an alias for `python`.
     """
+    app.ensure_environment_plugin_dependencies()
+
     project = app.project
 
     included_variables = {}
@@ -169,14 +160,14 @@ def run(
     with project.location.as_cwd():
         for env_name in environments:
             environment = app.get_environment(env_name)
+            if not environment.exists():
+                try:
+                    environment.check_compatibility()
+                except Exception as e:  # noqa: BLE001
+                    if ignore_compat or matrix_selected:
+                        incompatible[environment.name] = str(e)
+                        continue
 
-            try:
-                environment.check_compatibility()
-            except Exception as e:
-                if ignore_compat or matrix_selected:
-                    incompatible[environment.name] = str(e)
-                    continue
-                else:
                     app.abort(f'Environment `{env_name}` is incompatible: {e}')
 
             any_compatible = True
