@@ -684,8 +684,10 @@ class TestSources:
         config = {'tool': {'hatch': {'build': {'sources': {'': 'renamed'}}}}}
         builder = MockBuilder(str(isolation), config=config)
 
-        with pytest.raises(ValueError, match='Source #1 in field `tool.hatch.build.sources` cannot be an empty string'):
-            _ = builder.config.sources
+        assert len(builder.config.sources) == 1
+        assert builder.config.sources[''] == pjoin('renamed', '')
+        assert builder.config.get_distribution_path('bar.py') == pjoin('renamed', 'bar.py')
+        assert builder.config.get_distribution_path(pjoin('foo', 'bar.py')) == pjoin('renamed', 'foo', 'bar.py')
 
     def test_global_mapping_path_empty_string(self, isolation):
         config = {'tool': {'hatch': {'build': {'sources': {'src/foo': ''}}}}}
@@ -757,10 +759,9 @@ class TestSources:
         builder = MockBuilder(str(isolation), config=config)
         builder.PLUGIN_NAME = 'foo'
 
-        with pytest.raises(
-            ValueError, match='Source #1 in field `tool.hatch.build.targets.foo.sources` cannot be an empty string'
-        ):
-            _ = builder.config.sources
+        assert len(builder.config.sources) == 1
+        assert builder.config.sources[''] == pjoin('renamed', '')
+        assert builder.config.get_distribution_path(pjoin('bar.py')) == pjoin('renamed', 'bar.py')
 
     def test_target_mapping_path_empty_string(self, isolation):
         config = {'tool': {'hatch': {'build': {'targets': {'foo': {'sources': {'src/foo': ''}}}}}}}
@@ -947,7 +948,7 @@ class TestForceInclude:
         }
 
 
-class TestIncludeOnly:
+class TestOnlyInclude:
     def test_default(self, isolation):
         builder = MockBuilder(str(isolation))
 
@@ -1601,6 +1602,11 @@ class TestFileSelectionDefaults:
 
         assert builder.config.default_packages() == []
 
+    def test_only_include(self, isolation):
+        builder = MockBuilder(str(isolation))
+
+        assert builder.config.default_only_include() == []
+
     def test_global_exclude(self, isolation):
         builder = MockBuilder(str(isolation))
 
@@ -1882,7 +1888,7 @@ class TestPatternExclude:
 
     def test_override_default_global_exclude_patterns(self, isolation):
         builder = MockBuilder(str(isolation))
-        builder.config.default_global_exclude = lambda: []
+        builder.config.default_global_exclude = list
 
         assert builder.config.exclude_spec is None
         assert not builder.config.path_is_excluded('.git/file')
