@@ -41,7 +41,10 @@ def test_nonexistent(isolation):
         CustomBuilder(str(isolation), config=config)
 
 
-def test_default(hatch, helpers, temp_dir):
+def test_default(hatch, helpers, temp_dir, config_file):
+    config_file.model.template.plugins['default']['src-layout'] = False
+    config_file.save()
+
     project_name = 'My.App'
 
     with temp_dir.as_cwd():
@@ -73,8 +76,8 @@ def test_default(hatch, helpers, temp_dir):
                 return CustomWheelBuilder
 
             class CustomWheelBuilder(WheelBuilder):
-                def build(self, *args, **kwargs):
-                    for i, artifact in enumerate(super().build(*args, **kwargs)):
+                def build(self, **kwargs):
+                    for i, artifact in enumerate(super().build(**kwargs)):
                         build_dir = os.path.dirname(artifact)
                         new_path = os.path.join(build_dir, f'{self.PLUGIN_NAME}-{i}.whl')
                         os.replace(artifact, new_path)
@@ -116,7 +119,10 @@ def test_default(hatch, helpers, temp_dir):
         assert zip_info.date_time == (2020, 2, 2, 0, 0, 0)
 
 
-def test_explicit_path(hatch, helpers, temp_dir):
+def test_explicit_path(hatch, helpers, temp_dir, config_file):
+    config_file.model.template.plugins['default']['src-layout'] = False
+    config_file.save()
+
     project_name = 'My.App'
 
     with temp_dir.as_cwd():
@@ -149,8 +155,8 @@ def test_explicit_path(hatch, helpers, temp_dir):
                 return CustomWheelBuilder
 
             class CustomWheelBuilder(WheelBuilder):
-                def build(self, *args, **kwargs):
-                    for i, artifact in enumerate(super().build(*args, **kwargs)):
+                def build(self, **kwargs):
+                    for i, artifact in enumerate(super().build(**kwargs)):
                         build_dir = os.path.dirname(artifact)
                         new_path = os.path.join(build_dir, f'{self.PLUGIN_NAME}-{i}.whl')
                         os.replace(artifact, new_path)
@@ -231,9 +237,8 @@ def test_no_subclass(hatch, helpers, temp_dir):
     with pytest.raises(
         ValueError,
         match=re.escape(f'Unable to find a subclass of `BuilderInterface` in `foo/{DEFAULT_BUILD_SCRIPT}`: {temp_dir}'),
-    ):
-        with project_path.as_cwd():
-            CustomBuilder(str(project_path), config=config)
+    ), project_path.as_cwd():
+        CustomBuilder(str(project_path), config=config)
 
 
 def test_multiple_subclasses(hatch, helpers, temp_dir):
@@ -277,6 +282,5 @@ def test_multiple_subclasses(hatch, helpers, temp_dir):
             f'Multiple subclasses of `BuilderInterface` found in `foo/{DEFAULT_BUILD_SCRIPT}`, select '
             f'one by defining a function named `get_builder`: {temp_dir}'
         ),
-    ):
-        with project_path.as_cwd():
-            CustomBuilder(str(project_path), config=config)
+    ), project_path.as_cwd():
+        CustomBuilder(str(project_path), config=config)
