@@ -1,8 +1,11 @@
+import os
+
 from hatch.config.constants import AppEnvVars
 from hatch.project.core import Project
+from hatchling.utils.constants import DEFAULT_CONFIG_FILE
 
 
-def test_unknown(hatch, temp_dir_data, helpers, config_file):
+def test_unknown(hatch, temp_dir_data, helpers):
     project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
@@ -23,7 +26,7 @@ def test_unknown(hatch, temp_dir_data, helpers, config_file):
     )
 
 
-def test_nonexistent(hatch, temp_dir_data, config_file):
+def test_nonexistent(hatch, temp_dir_data):
     project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
@@ -277,7 +280,7 @@ def test_matrix_all_local_directory(hatch, helpers, temp_dir_data, config_file):
     assert not env_data_path.is_dir()
 
 
-def test_incompatible_ok(hatch, helpers, temp_dir_data, config_file):
+def test_incompatible_ok(hatch, helpers, temp_dir_data):
     project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
@@ -299,7 +302,7 @@ def test_incompatible_ok(hatch, helpers, temp_dir_data, config_file):
     assert not result.output
 
 
-def test_active(hatch, temp_dir_data, helpers, config_file):
+def test_active(hatch, temp_dir_data, helpers):
     project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
@@ -370,3 +373,78 @@ def test_active_override(hatch, helpers, temp_dir_data, config_file):
     )
 
     assert not storage_path.is_dir()
+
+
+def test_plugin_dependencies_unmet(hatch, helpers, temp_dir_data, config_file, mock_plugin_installation):
+    config_file.model.template.plugins['default']['tests'] = False
+    config_file.save()
+
+    project_name = 'My.App'
+
+    with temp_dir_data.as_cwd():
+        result = hatch('new', project_name)
+
+    assert result.exit_code == 0, result.output
+
+    project_path = temp_dir_data / 'my-app'
+
+    project = Project(project_path)
+    helpers.update_project_environment(project, 'default', {'skip-install': True, **project.config.envs['default']})
+    helpers.update_project_environment(project, 'foo', {})
+    helpers.update_project_environment(project, 'bar', {})
+
+    with project_path.as_cwd():
+        result = hatch('env', 'create', 'foo')
+
+    assert result.exit_code == 0, result.output
+
+    with project_path.as_cwd():
+        result = hatch('env', 'create', 'bar')
+
+    assert result.exit_code == 0, result.output
+
+    env_data_path = temp_dir_data / 'data' / 'env' / 'virtual'
+    assert env_data_path.is_dir()
+
+    project_data_path = env_data_path / project_path.name
+    assert project_data_path.is_dir()
+
+    storage_dirs = list(project_data_path.iterdir())
+    assert len(storage_dirs) == 1
+
+    storage_path = storage_dirs[0]
+    assert len(storage_path.name) == 8
+
+    env_dirs = list(storage_path.iterdir())
+    assert len(env_dirs) == 2
+
+    foo_env_path = storage_path / 'foo'
+    bar_env_path = storage_path / 'bar'
+
+    assert foo_env_path.is_dir()
+    assert bar_env_path.is_dir()
+
+    dependency = os.urandom(16).hex()
+    (project_path / DEFAULT_CONFIG_FILE).write_text(
+        helpers.dedent(
+            f"""
+            [env]
+            requires = ["{dependency}"]
+            """
+        )
+    )
+
+    with project_path.as_cwd():
+        result = hatch('env', 'remove', 'bar')
+
+    assert result.exit_code == 0, result.output
+    assert result.output == helpers.dedent(
+        """
+        Syncing environment plugin requirements
+        Removing environment: bar
+        """
+    )
+    helpers.assert_plugin_installation(mock_plugin_installation, [dependency])
+
+    assert foo_env_path.is_dir()
+    assert not bar_env_path.is_dir()
