@@ -1,11 +1,14 @@
+import os
+
 import pytest
 
 from hatch.project.core import Project
 from hatch.utils.structures import EnvVars
+from hatchling.utils.constants import DEFAULT_CONFIG_FILE
 
 
 @pytest.fixture(scope='module', autouse=True)
-def terminal_width():
+def _terminal_width():
     with EnvVars({'COLUMNS': '200'}):
         yield
 
@@ -436,14 +439,57 @@ def test_context_formatting(hatch, helpers, temp_dir, config_file):
         +======+=========+==============+=======================+
         | foo  | virtual | pydantic     | BAR=FOO_BAR           |
         +------+---------+--------------+-----------------------+
-                                  Matrices
-        +---------+---------+------------+-------------------------+
-        | Name    | Type    | Envs       | Dependencies            |
-        +=========+=========+============+=========================+
-        | default | virtual | py39-9000  | foo @ {root:uri}/../foo |
-        |         |         | py39-3.14  |                         |
-        |         |         | py310-9000 |                         |
-        |         |         | py310-3.14 |                         |
-        +---------+---------+------------+-------------------------+
+                                 Matrices
+        +---------+---------+------------+------------------------+
+        | Name    | Type    | Envs       | Dependencies           |
+        +=========+=========+============+========================+
+        | default | virtual | py39-9000  | foo@ {root:uri}/../foo |
+        |         |         | py39-3.14  |                        |
+        |         |         | py310-9000 |                        |
+        |         |         | py310-3.14 |                        |
+        +---------+---------+------------+------------------------+
         """
     )
+
+
+def test_plugin_dependencies_unmet(hatch, helpers, temp_dir, config_file, mock_plugin_installation):
+    config_file.model.template.plugins['default']['tests'] = False
+    config_file.save()
+
+    project_name = 'My.App'
+
+    with temp_dir.as_cwd():
+        result = hatch('new', project_name)
+
+    assert result.exit_code == 0, result.output
+
+    project_path = temp_dir / 'my-app'
+    data_path = temp_dir / 'data'
+    data_path.mkdir()
+
+    dependency = os.urandom(16).hex()
+    (project_path / DEFAULT_CONFIG_FILE).write_text(
+        helpers.dedent(
+            f"""
+            [env]
+            requires = ["{dependency}"]
+            """
+        )
+    )
+
+    with project_path.as_cwd():
+        result = hatch('env', 'show', '--ascii')
+
+    assert result.exit_code == 0, result.output
+    assert helpers.remove_trailing_spaces(result.output) == helpers.dedent(
+        """
+        Syncing environment plugin requirements
+             Standalone
+        +---------+---------+
+        | Name    | Type    |
+        +=========+=========+
+        | default | virtual |
+        +---------+---------+
+        """
+    )
+    helpers.assert_plugin_installation(mock_plugin_installation, [dependency])
