@@ -342,7 +342,7 @@ def test_prompt(hatch, devpi, temp_dir_cache, helpers, published_project_name, c
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
         f"""
-        Enter your username [__TOKEN__]: {devpi.user}
+        Enter your username [__token__]: {devpi.user}
         Enter your credentials:{' '}
         {artifacts[0].relative_to(path)} ... success
 
@@ -385,7 +385,7 @@ def test_initialize_auth(hatch, devpi, temp_dir_cache, helpers, published_projec
     assert result.exit_code == 0, result.output
     assert result.output == helpers.dedent(
         f"""
-        Enter your username [__TOKEN__]: {devpi.user}
+        Enter your username [__token__]: {devpi.user}
         Enter your credentials:{' '}
         """
     )
