@@ -20,7 +20,7 @@ def get_files(**kwargs):
 
         files.append(f)
 
-    files.append(
+    files.extend((
         File(
             Path(metadata_directory, 'WHEEL'),
             f"""\
@@ -29,9 +29,7 @@ Generator: hatchling {__version__}
 Root-Is-Purelib: true
 Tag: py3-none-any
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(metadata_directory, 'METADATA'),
             f"""\
@@ -41,8 +39,8 @@ Version: 0.0.1
 License-File: LICENSE.txt
 Requires-Python: >3
 """,
-        )
-    )
+        ),
+    ))
 
     record_file = File(Path(metadata_directory, 'RECORD'), '')
     update_record_file_contents(record_file, files)
