@@ -1,5 +1,6 @@
 import json
 import os
+import re
 import sys
 
 import pytest
@@ -14,7 +15,7 @@ def test_initialization_does_not_create(temp_dir, platform):
 
     assert not venv.exists()
 
-    with pytest.raises(OSError, match='Unable to locate executables directory'):
+    with pytest.raises(OSError, match=f'Unable to locate executables directory within: {re.escape(str(venv_dir))}'):
         _ = venv.executables_directory
 
 
@@ -43,7 +44,8 @@ def test_executables_directory(temp_dir, platform):
         if entry.name.startswith('py'):
             break
     else:  # no cov
-        raise AssertionError('Unable to locate Python executable')
+        msg = 'Unable to locate Python executable'
+        raise AssertionError(msg)
 
 
 def test_activation(temp_dir, platform):
